StyleSet

Struct StyleSet 

pub struct StyleSet {
Show 17 fields pub name: String, pub author: String, pub is_dark: bool, pub primary: Style, pub secondary: Style, pub muted: Style, pub border: Style, pub border_muted: Style, pub selection: Style, pub cursor: Style, pub cursor_muted: Style, pub error: Style, pub warning: Style, pub info: Style, pub success: Style, pub highlight: Style, pub link: Style, /* private fields */
}
The main StyleSet struct with predefined styles as named fields

Fields

name: String

Human-readable theme name.

author: String

Theme author name or contact. Empty string if not specified.

is_dark: bool

true for dark themes, false for light themes.

primary: Style

The primary style for normal text and other elements.

secondary: Style

A secondary style, for sidebars or other secondary elements.

muted: Style

A muted style for disabled/deselected elements.

border: Style

A style for borders and other decorative elements.

border_muted: Style

A style for disabled borders and other decorative elements.

selection: Style

A style for selected text or elements.

cursor: Style

A cursor style

cursor_muted: Style

A disabled cursor style

error: Style

A style for errors

warning: Style

A style for warnings

info: Style

A style for informative text or elements such as spinners

success: Style

It works!

highlight: Style

A style for highlighted information or elements

link: Style

URLs or other links

Implementations

Source

impl StyleSet

pub fn from_name(name: &str) -> Self

Create a StyleSet from a theme name, with reasonable fallbacks.

Accepts any common case format: "Nord Dark", "nord-dark", "NordDark".

pub fn from_default_light_cfg() -> Self

Create a light StyleSet from the user’s configured light default.

Fallback order:

  1. User configured light theme.
  2. Built-in default light theme.
pub fn insert_custom(&mut self, key: impl Into<String>, style: Style)

Add a custom style by name

pub fn get_custom(&self, key: &str) -> Option<&Style>

Get a custom style by name